Description Usage Arguments Value Examples
View source: R/compare_response.R
User Inputs Size Comparison
1 | compare_response(res1, res2)
|
res1 |
This is the first value the user inputs |
res2 |
This is the second value the user inputs |
This returns a line with the result of comparison of two inputs
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.