Description Usage Arguments Value Examples
View source: R/get_extreme_middle.R
Get the AveraGe of Extreme values in Data
1 | get_extreme_middle(data = c(1, 2, 3, 4))
|
data |
This should be a column or row of data |
Returns the average of the largest and the smallest number inside the data colomn/row
1 | get_extreme_middle(c(1,2))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.