Description Usage Arguments Value Examples
View source: R/is_rightangle.R
Check if Triangle has a Right Angle
1 | is_rightangle(a = 3, b = 4, c = 5)
|
a |
Length of 1st side, doesn't need to be the longest or shortest |
b |
Length of 2nd side, doesn't need to be the longest or shortest |
c |
Length of 3rd side, doesn't need to be the longest or shortest |
The function returns true if it is right angle triangle, else false.
1 | is_rightangle(6,8,10)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.