mean_binomial_sample: Mean of Binomial Samples

Description Usage Arguments Value Examples

View source: R/mean_binomial_sample.R

Description

Mean of Binomial Samples

Usage

1
mean_binomial_sample(samplesize, n = 2, p = 0.5)

Arguments

samplesize

This is the size of the random sample that you want to generate

n

This is the number of trials in the binomial distribution

p

This is the probability in the binomial distribution

Value

The function returns the mean of the random sample of binomial distribution generated.

Examples

1

hzwangjiren/jiren441final documentation built on Jan. 1, 2021, 3:23 a.m.