window_backtesting: Moving Window Backtesting Function

Description Usage Arguments Value

View source: R/window_backtesting.R

Description

Moving Window Backtesting Function

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
window_backtesting(
  model,
  data,
  orig,
  h,
  xreg = NULL,
  fixed = NULL,
  inc.mean = TRUE,
  reest = 1
)

Arguments

model

This is the linear regression model used on time series

data

This is the time series data

orig

This is the number of data in the window

h

This is the number of steps in prediction

xreg

Usually go by default

fixed

Usually go by Null

inc.mean

Usually go by true

reest

Time for the reestimation, usually go by 1.

Value

This function returns the RMSE and Mean Absolute Error of the model


hzwangjiren/jiren441final documentation built on Jan. 1, 2021, 3:23 a.m.