Description Usage Arguments Value Examples
View source: R/mean_binomial_sample.R
Mean of Binomial Samples
1 | mean_binomial_sample(samplesize, n = 2, p = 0.5)
|
samplesize |
This is the size of the random sample that you want to generate |
n |
This is the number of trials in the binomial distribution |
p |
This is the probability in the binomial distribution |
The function returns the mean of the random sample of binomial distribution generated.
1 | mean_binomial_sample(50,10,0.5)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.