Description Usage Arguments Value
View source: R/window_backtesting.R
Moving Window Backtesting Function
1 2 3 4 5 6 7 8 9 10 | window_backtesting(
model,
data,
orig,
h,
xreg = NULL,
fixed = NULL,
inc.mean = TRUE,
reest = 1
)
|
model |
This is the linear regression model used on time series |
data |
This is the time series data |
orig |
This is the number of data in the window |
h |
This is the number of steps in prediction |
xreg |
Usually go by default |
fixed |
Usually go by Null |
inc.mean |
Usually go by true |
reest |
Time for the reestimation, usually go by 1. |
This function returns the RMSE and Mean Absolute Error of the model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.